dag_longest_path

Function dag_longest_path 

pub fn dag_longest_path<G>(graph: &G) -> Result<Option<WeightedPath<G::Node>>>
where G: IndexGraphView,
Returns a deterministic longest path in a directed acyclic graph.

Every accepted edge has unit cost. An empty graph returns None.

Errors

Returns an error when the graph is cyclic or the length overflows.