dag_longest_path_length

Function dag_longest_path_length 

pub fn dag_longest_path_length<G>(graph: &G) -> Result<Option<u64>>
where G: IndexGraphView,
Returns the number of edges in a deterministic longest DAG path.

Errors

Returns an error when the graph is cyclic or the length overflows.