pub fn graph6_decode(input: &str) -> Result<UndirectedTopology>Expand description
Decodes one Graph6 record into a compact undirected topology.
Errors
Returns an error for malformed headers, lengths, padding, or capacity.
pub fn graph6_decode(input: &str) -> Result<UndirectedTopology>Decodes one Graph6 record into a compact undirected topology.
Returns an error for malformed headers, lengths, padding, or capacity.