union

Function union 

pub fn union<Left, Right>(
    left: &Left,
    right: &Right,
) -> Result<TopologyProjection<Left::Node>>
where Left: IndexGraphView, Right: IndexGraphView<Node = Left::Node>,
Materializes the simple union of two graphs by node identity.

Errors

Returns an error when the compact result exceeds topology capacity.