pub struct BiconnectedComponents<Node, Edge> { /* private fields */ }Expand description
Deterministic vertex-biconnected edge blocks and their cut vertices.
Implementations
Sourceimpl<Node, Edge> BiconnectedComponents<Node, Edge>
impl<Node, Edge> BiconnectedComponents<Node, Edge>
Sourcepub fn components(&self) -> &[Vec<Edge>]
pub fn components(&self) -> &[Vec<Edge>]
Returns canonical edge blocks, ordered by their smallest edge index.
Sourcepub fn component_count(&self) -> usize
pub fn component_count(&self) -> usize
Returns the number of edge blocks.
Sourcepub fn articulation_points(&self) -> &[Node]
pub fn articulation_points(&self) -> &[Node]
Returns cut vertices in canonical node-index order.
Sourcepub fn into_components(self) -> Vec<Vec<Edge>>
pub fn into_components(self) -> Vec<Vec<Edge>>
Consumes the result and returns its canonical edge blocks.