DenseMatrix

Struct DenseMatrix 

pub struct DenseMatrix<T> { /* private fields */ }

Implementations

Source

impl<T> DenseMatrix<T>

pub fn try_new(node_count: usize) -> Result<Self>

Creates a fixed-size directed adjacency matrix.

Errors

Returns an error when the dimensions exceed index or address capacity.

pub const fn node_count(&self) -> usize

pub const fn edge_count(&self) -> usize

pub fn get(&self, source: NodeIndex, target: NodeIndex) -> Option<&T>

pub fn get_mut( &mut self, source: NodeIndex, target: NodeIndex, ) -> Option<&mut T>

pub fn insert( &mut self, source: NodeIndex, target: NodeIndex, value: T, ) -> Result<Option<T>>

Inserts or replaces one directed edge value.

Errors

Returns an error when either endpoint is outside the fixed matrix.

pub fn remove(&mut self, source: NodeIndex, target: NodeIndex) -> Option<T>

pub fn outgoing( &self, source: NodeIndex, ) -> impl Iterator<Item = (NodeIndex, &T)>

pub fn incoming( &self, target: NodeIndex, ) -> impl Iterator<Item = (NodeIndex, &T)>

pub fn edges(&self) -> impl Iterator<Item = (NodeIndex, NodeIndex, &T)>

Source

impl<T: Clone> DenseMatrix<T>

pub fn insert_undirected( &mut self, left: NodeIndex, right: NodeIndex, value: T, ) -> Result<(Option<T>, Option<T>)>

Inserts the same value in both directions.

Errors

Returns an error when either endpoint is outside the fixed matrix.