DistanceAnalytics

Struct DistanceAnalytics 

pub struct DistanceAnalytics<Node> { /* private fields */ }
Exact unweighted distance metrics for a connected undirected graph.

Implementations

Source

impl<Node: Copy + Eq> DistanceAnalytics<Node>

pub fn eccentricities(&self) -> &[(Node, usize)]

Returns (node, eccentricity) pairs in canonical node-index order.

pub fn eccentricity(&self, node: Node) -> Option<usize>

Returns the eccentricity of node, if it belongs to the graph.

pub const fn radius(&self) -> usize

Returns the minimum eccentricity.

pub const fn diameter(&self) -> usize

Returns the maximum eccentricity.

pub fn center(&self) -> &[Node]

Returns all minimum-eccentricity nodes in canonical order.

pub fn periphery(&self) -> &[Node]

Returns all maximum-eccentricity nodes in canonical order.

pub fn into_eccentricities(self) -> Vec<(Node, usize)>

Consumes the result and returns its canonical eccentricity pairs.