RandomGraphGenerator

Struct RandomGraphGenerator 

pub struct RandomGraphGenerator { /* private fields */ }

Implementations

Source

impl RandomGraphGenerator

pub const fn new(seed: u64) -> Self

pub fn directed( &mut self, node_count: usize, numerator: u64, denominator: u64, ) -> Result<Topology>

Generates a directed Erdos-Renyi graph without self-loops.

Errors

Returns an error for an invalid probability or compact capacity overflow.

pub fn undirected( &mut self, node_count: usize, numerator: u64, denominator: u64, ) -> Result<UndirectedTopology>

Generates an undirected Erdos-Renyi graph without self-loops.

Errors

Returns an error for an invalid probability or compact capacity overflow.

pub fn dag( &mut self, node_count: usize, numerator: u64, denominator: u64, ) -> Result<Topology>

Generates a DAG with edges from lower to higher node ids.

Errors

Returns an error for an invalid probability or compact capacity overflow.