pub struct StableUndirectedPayloadGraph<NodePayload, EdgePayload> { /* private fields */ }Expand description
A mutable undirected payload graph with generation-checked stable keys.
Implementations
Sourceimpl<NodePayload, EdgePayload> StableUndirectedPayloadGraph<NodePayload, EdgePayload>
impl<NodePayload, EdgePayload> StableUndirectedPayloadGraph<NodePayload, EdgePayload>
pub const fn new() -> Self
pub fn with_capacity(nodes: usize, edges: usize) -> Self
Sourcepub fn add_node(&mut self, payload: NodePayload) -> Result<StableNodeKey>
pub fn add_node(&mut self, payload: NodePayload) -> Result<StableNodeKey>
Adds a node payload and returns a generation-stable key.
Errors
Returns an error when the stable index space is exhausted.
Sourcepub fn add_edge(
&mut self,
source: StableNodeKey,
target: StableNodeKey,
payload: EdgePayload,
) -> Result<StableEdgeKey>
pub fn add_edge( &mut self, source: StableNodeKey, target: StableNodeKey, payload: EdgePayload, ) -> Result<StableEdgeKey>
Adds one undirected edge. A self-loop occupies one incidence entry.
Errors
Returns an error for stale endpoints or exhausted edge indices.
pub fn node(&self, key: StableNodeKey) -> Option<&NodePayload>
pub fn node_mut(&mut self, key: StableNodeKey) -> Option<&mut NodePayload>
pub fn edge(&self, key: StableEdgeKey) -> Option<&EdgePayload>
pub fn edge_mut(&mut self, key: StableEdgeKey) -> Option<&mut EdgePayload>
pub fn edge_endpoints( &self, key: StableEdgeKey, ) -> Option<EdgeEndpoints<StableNodeKey>>
pub fn nodes(&self) -> impl Iterator<Item = (StableNodeKey, &NodePayload)>
pub fn edges(&self) -> impl Iterator<Item = (StableEdgeKey, &EdgePayload)>
pub fn incident_edges( &self, node: StableNodeKey, ) -> impl DoubleEndedIterator<Item = StableEdgeKey> + ExactSizeIterator + '_
pub const fn node_count(&self) -> usize
pub const fn edge_count(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourceimpl<NodePayload, EdgePayload> StableUndirectedPayloadGraph<NodePayload, EdgePayload>
impl<NodePayload, EdgePayload> StableUndirectedPayloadGraph<NodePayload, EdgePayload>
Sourcepub fn freeze(
self,
) -> Result<FrozenUndirectedPayloadGraph<NodePayload, EdgePayload>>
pub fn freeze( self, ) -> Result<FrozenUndirectedPayloadGraph<NodePayload, EdgePayload>>
Compacts live stable slots into immutable undirected incidence CSR.
Errors
Returns an error if compact index capacity is exhausted.
Sourceimpl<NodePayload, EdgePayload> StableUndirectedPayloadGraph<NodePayload, EdgePayload>
impl<NodePayload, EdgePayload> StableUndirectedPayloadGraph<NodePayload, EdgePayload>
pub fn remove_edge(&mut self, key: StableEdgeKey) -> Option<EdgePayload>
pub fn remove_node(&mut self, key: StableNodeKey) -> Option<NodePayload>
Sourcepub fn set_edge_endpoints(
&mut self,
key: StableEdgeKey,
source: StableNodeKey,
target: StableNodeKey,
) -> Result<bool>
pub fn set_edge_endpoints( &mut self, key: StableEdgeKey, source: StableNodeKey, target: StableNodeKey, ) -> Result<bool>
Moves an edge without changing its stable key or payload.
Errors
Returns an error when either new endpoint is stale.