pub fn chain_decomposition<G>(graph: &G) -> ChainDecomposition<G::Node, G::Edge>where
G: IndexUndirectedGraphView,Expand description
Computes a chain decomposition of every connected component in O(V + E).
Unlike simple-graph-only variants, this preserves parallel edge identities and represents a self-loop as a one-edge chain.