pub fn union<Left, Right>(
left: &Left,
right: &Right,
) -> Result<TopologyProjection<Left::Node>>Expand description
Materializes the simple union of two graphs by node identity.
Errors
Returns an error when the compact result exceeds topology capacity.