pub struct DistanceAnalytics<Node> { /* private fields */ }Expand description
Exact unweighted distance metrics for a connected undirected graph.
Implementations
Sourceimpl<Node: Copy + Eq> DistanceAnalytics<Node>
impl<Node: Copy + Eq> DistanceAnalytics<Node>
Sourcepub fn eccentricities(&self) -> &[(Node, usize)]
pub fn eccentricities(&self) -> &[(Node, usize)]
Returns (node, eccentricity) pairs in canonical node-index order.
Sourcepub fn eccentricity(&self, node: Node) -> Option<usize>
pub fn eccentricity(&self, node: Node) -> Option<usize>
Returns the eccentricity of node, if it belongs to the graph.
Sourcepub fn into_eccentricities(self) -> Vec<(Node, usize)>
pub fn into_eccentricities(self) -> Vec<(Node, usize)>
Consumes the result and returns its canonical eccentricity pairs.