pub struct RandomGraphGenerator { /* private fields */ }Implementations
Sourceimpl RandomGraphGenerator
impl RandomGraphGenerator
pub const fn new(seed: u64) -> Self
Sourcepub fn directed(
&mut self,
node_count: usize,
numerator: u64,
denominator: u64,
) -> Result<Topology>
pub fn directed( &mut self, node_count: usize, numerator: u64, denominator: u64, ) -> Result<Topology>
Generates a directed Erdos-Renyi graph without self-loops.
Errors
Returns an error for an invalid probability or compact capacity overflow.
Sourcepub fn undirected(
&mut self,
node_count: usize,
numerator: u64,
denominator: u64,
) -> Result<UndirectedTopology>
pub fn undirected( &mut self, node_count: usize, numerator: u64, denominator: u64, ) -> Result<UndirectedTopology>
Generates an undirected Erdos-Renyi graph without self-loops.
Errors
Returns an error for an invalid probability or compact capacity overflow.