pub struct UndirectedTopology { /* private fields */ }Implementations
Sourceimpl UndirectedTopology
impl UndirectedTopology
Sourcepub fn try_from_edges(
node_count: usize,
edges: impl IntoIterator<Item = EdgeEndpoints>,
) -> Result<Self>
pub fn try_from_edges( node_count: usize, edges: impl IntoIterator<Item = EdgeEndpoints>, ) -> Result<Self>
Builds an undirected topology with compact incidence CSR.
Self-loops occupy one incidence entry and report degree two.
Errors
Returns an error for capacity overflow or an endpoint outside the graph.
pub const fn node_count(&self) -> usize
pub const fn edge_count(&self) -> usize
pub fn contains_node(&self, node: NodeIndex) -> bool
pub fn contains_edge(&self, edge: EdgeIndex) -> bool
pub fn edge_endpoints(&self, edge: EdgeIndex) -> Option<EdgeEndpoints>
pub fn incident_edges( &self, node: NodeIndex, ) -> impl DoubleEndedIterator<Item = EdgeIndex> + ExactSizeIterator + '_
pub fn incident_edge_at( &self, node: NodeIndex, offset: usize, ) -> Option<EdgeIndex>
pub fn neighbors( &self, node: NodeIndex, ) -> impl DoubleEndedIterator<Item = NodeIndex> + ExactSizeIterator + '_
pub fn degree(&self, node: NodeIndex) -> Option<usize>